<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
return array(
  array(
    'title' => 'Announcements',
    'description' => 'Displays recent announcements.',
    'category' => 'Core',
    'type' => 'widget',
    'name' => 'announcement.list-announcements',
    'isPaginated' => true,
    'autoEdit' => true,
    'defaultParams' => array(
      'title' => 'Announcements',
    ),
    'requirements' => array(
      'no-subject',
    ),
  ),
) ?>
