<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Announcement_Form_Admin_Delete extends Engine_Form
{
  public function init()
  {
    $this->setTitle('Delete Announcement')
      ->setDescription('Are you sure you want to delete this announcement?');

    $this->addElement('Button', 'submit', array(
      'label' => 'Delete Announcement',
      'type' => 'submit',
    ));

    $this->addElement('Button', 'cancel', array(
      'label' => 'cancel',
      'onclick' => 'window.proxyLocation.href="'.Zend_Controller_Front::getInstance()->assemble().'";'
    ));
  }
}
