
/* $Id: main.css 8825 2011-04-09 01:34:20Z john $ */



/*
ANNOUNCEMENTS WIDGET
Used to display announcements.
*/
#announcements{
  padding: 7px;
  border-top-width: 1px;
  margin-bottom: 15px;
}

/* ITEM TYPE ICONS */
.item_icon_announcement:before{
 content: "\f024";
 font-family:'Font Awesome 6 Free';
}
