<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
?>
<?php echo $this->partial('_admin_breadcrumb.tpl', 'core', array('parentMenu' => "core_admin_main_manage", 'parentMenuItemName' => 'core_admin_main_manage_announcements', 'lastMenuItemName' => 'Edit Announcement')); ?>

<?php
  $this->headLink()->appendStylesheet($this->layout()->staticBaseUrl."externals/selectize/css/normalize.css");
$headScript = new Zend_View_Helper_HeadScript();
$headScript->prependFile($this->layout()->staticBaseUrl.'externals/jQuery/jquery.min.js');
$headScript->appendFile($this->layout()->staticBaseUrl.'externals/selectize/js/selectize.js');
?>
<div class="settings">
  <?php echo $this->form->render($this) ?>
</div>
<style>
  .selectize-input{
    min-width: 200px;
  }
  .selectize-control.multi .selectize-input [data-value]{
    background-color: blue;
    color: white;
  }
</style>
<script type="application/javascript">
    scriptJquery('select[multiple=multiple]').closest('div').css('overflow',"visible");
    scriptJquery('select[multiple=multiple]').selectize({});
</script>
<script type="application/javascript">
  scriptJquery('.core_admin_main_manage').parent().addClass('active');
  scriptJquery('.core_admin_main_manage_announcements').addClass('active');
</script>
