<?php
/**
  * Ahead WebSoft Technologies Pvt Ltd.
  * @copyright  Copyright 2006-2026 Ahead WebSoft Technologies Pvt Ltd.
  * @license    https://www.socialengine.com/policies
*/
class Announcement_Form_Admin_Filter extends Engine_Form
{
  public function init()
  {
    $this
      ->setAttribs(array(
        'id' => 'filter_form',
        'class' => 'global_form_box',
      ));

    $this->addElement('Hidden', 'orderby', array(
      'order' => 1
    ));

    $this->addElement('Hidden', 'orderby_direction', array(
      'order' => 2
    ));
  }
}
