ALTER TABLE `engine4_announcement_announcements`
ADD `networks` text COLLATE utf8mb4_unicode_ci;

ALTER TABLE `engine4_announcement_announcements`
ADD `member_levels` text COLLATE utf8mb4_unicode_ci;

ALTER TABLE `engine4_announcement_announcements`
ADD `profile_types` text COLLATE utf8mb4_unicode_ci;